@@ -164,13 +164,6 @@ impl Fold for Normalizer {
 
         n
     }
-
-    fn fold_str(&mut self, s: Str) -> Str {
-        Str {
-            kind: Default::default(),
-            ..s
-        }
-    }
 }
 
 pub(crate) fn test_transform<F, P>(
